@@ -87,7 +87,7 @@ extern "C" {
 
     String scim_setup_module_get_description (void)
     {
-        return String (_("An Canna IMEngine Module."));
+        return String (_("A Canna IMEngine Module."));
     }
 
     void scim_setup_module_load_config (const ConfigPointer &config)
@@ -148,14 +148,6 @@ struct ComboConfigCandidate
     const char *data;
 };
 
-enum {
-    COLUMN_LABEL = 0,
-    COLUMN_VALUE = 1,
-    COLUMN_DESC  = 2,
-    COLUMN_DATA  = 3,
-    N_COLUMNS    = 4,
-};
-
 // Internal data declaration.
 static bool __have_changed    = true;
 
@@ -300,6 +292,46 @@ create_check_button (const char *config_key)
     return entry->widget;
 }
 
+GtkWidget *
+create_entry (const char *config_key, GtkTable *table, int idx)
+{
+    StringConfigData *entry = find_string_config_entry (config_key);
+    if (!entry)
+        return NULL;
+
+    (entry)->widget = gtk_entry_new ();
+    GtkWidget *label = NULL;
+    if (_(entry->label) && *_(entry->label)) {
+        label = gtk_label_new (NULL);
+        gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _(entry->label));
+        gtk_widget_show (label);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_misc_set_padding (GTK_MISC (label), 4, 0);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, idx, idx + 1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (GTK_FILL), 4, 4);
+        gtk_label_set_mnemonic_widget (GTK_LABEL (label),
+                                       GTK_WIDGET (entry->widget));
+    }
+
+    g_signal_connect ((gpointer) (entry)->widget, "changed",
+                      G_CALLBACK (on_default_editable_changed),
+                      entry);
+    gtk_widget_show (GTK_WIDGET (entry->widget));
+    gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (entry->widget),
+                      1, 2, idx, idx + 1,
+                      (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
+                      (GtkAttachOptions) (GTK_FILL), 4, 4);
+
+    if (!__widget_tooltips)
+        __widget_tooltips = gtk_tooltips_new();
+    if (entry->tooltip)
+        gtk_tooltips_set_tip (__widget_tooltips, GTK_WIDGET (entry->widget),
+                              _(entry->tooltip), NULL);
+
+    return GTK_WIDGET (entry->widget);
+}
+
 GtkWidget *
 create_combo (const char *config_key, gpointer candidates_p,
               GtkTable *table, gint idx)
@@ -347,46 +379,6 @@ create_combo (const char *config_key, gpointer candidates_p,
     return GTK_WIDGET (entry->widget);
 }
 
-GtkWidget *
-create_entry (const char *config_key, GtkTable *table, int idx)
-{
-    StringConfigData *entry = find_string_config_entry (config_key);
-    if (!entry)
-        return NULL;
-
-    (entry)->widget = gtk_entry_new ();
-    GtkWidget *label = NULL;
-    if (_(entry->label) && *_(entry->label)) {
-        label = gtk_label_new (NULL);
-        gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _(entry->label));
-        gtk_widget_show (label);
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-        gtk_misc_set_padding (GTK_MISC (label), 4, 0);
-        gtk_table_attach (GTK_TABLE (table), label, 0, 1, idx, idx + 1,
-                          (GtkAttachOptions) (GTK_FILL),
-                          (GtkAttachOptions) (GTK_FILL), 4, 4);
-        gtk_label_set_mnemonic_widget (GTK_LABEL (label),
-                                       GTK_WIDGET (entry->widget));
-    }
-
-    g_signal_connect ((gpointer) (entry)->widget, "changed",
-                      G_CALLBACK (on_default_editable_changed),
-                      entry);
-    gtk_widget_show (GTK_WIDGET (entry->widget));
-    gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (entry->widget),
-                      1, 2, idx, idx + 1,
-                      (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
-                      (GtkAttachOptions) (GTK_FILL), 4, 4);
-
-    if (!__widget_tooltips)
-        __widget_tooltips = gtk_tooltips_new();
-    if (entry->tooltip)
-        gtk_tooltips_set_tip (__widget_tooltips, GTK_WIDGET (entry->widget),
-                              _(entry->tooltip), NULL);
-
-    return GTK_WIDGET (entry->widget);
-}
-
 GtkWidget *
 create_key_select_button (const char *config_key, GtkTable *table, int idx)
 {
@@ -469,10 +461,11 @@ create_mode_page ()
     gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
     gtk_widget_show (table);
 
-    //
-    create_combo (SCIM_CANNA_CONFIG_ON_OFF, on_off_modes, GTK_TABLE (table), 0);
+    // Default mode
+    create_combo (SCIM_CANNA_CONFIG_ON_OFF, on_off_modes,
+                  GTK_TABLE (table), 0);
 
-    //
+    //ON/OFF key
     create_entry (SCIM_CANNA_CONFIG_ON_OFF_KEY, GTK_TABLE (table), 1);
     create_key_select_button (SCIM_CANNA_CONFIG_ON_OFF_KEY,
                               GTK_TABLE (table), 1);
@@ -480,6 +473,39 @@ create_mode_page ()
     return vbox;
 }
 
+static GtkWidget *
+create_about_page ()
+{
+    GtkWidget *vbox, *label;
+    gchar str[256];
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox);
+
+    g_snprintf (
+        str, 256,
+        _("<span size=\"20000\">"
+          "%s-%s"
+          "</span>\n\n"
+
+          "<span size=\"16000\" style=\"italic\">"
+          "A Japanese input method module\nfor SCIM using Canna"
+          "</span>\n\n\n\n"
+
+          "<span size=\"12000\">"
+          "Copyright 2005-2006, Takuro Ashie &lt;ashie@homa.ne.jp&gt;"
+          "</span>"),
+        PACKAGE, PACKAGE_VERSION);
+
+    label = gtk_label_new (NULL);
+    gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
+    gtk_label_set_markup (GTK_LABEL (label), str);
+    gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+    gtk_widget_show (label);
+
+    return vbox;
+}
+
 static GtkWidget *
 create_setup_window ()
 {
@@ -504,6 +530,12 @@ create_setup_window ()
     gtk_widget_show (label);
     gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
+    // Create the third page.
+    page = create_about_page ();
+    label = gtk_label_new (_("About"));
+    gtk_widget_show (label);
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+
     // for preventing enabling left arrow.
     gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 1);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
